@@ -25,11 +25,11 @@ except:
 
 class Client(Singleton):
     @staticmethod
-    def get_client(host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=True):
+    def get_client(host, redis_client, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=True):
         client = Client(host, redis_client, mq_manager, async_mq_mode, init_redis=init_redis)
         return client
     
-    def __init__(self, host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=True) -> None:
+    def __init__(self, host, redis_client, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=True) -> None:
         if not self.need_init():
             return
         
