@@ -31,7 +31,14 @@ class MQManager(Singleton):
         self.inited = True
 
     async def get_mq_conn(self):
-        return await open_connection(self.host, self.port)
+        if not hasattr(self, 'mq'):
+            self.mq = await open_connection(self.host, self.port)
+        
+        if self.mq.status == 0:
+            del self.mq
+            return await self.get_mq_conn()
+        else:
+            return self.mq
             
     def _encode_message(self, message):
         if isinstance(message, str):
@@ -84,12 +91,12 @@ class MQManager(Singleton):
             if mq is None:
                 mq = await self.get_mq_conn()
 
-            ret = await mq.pub(topic, message)
+            ret = (await mq.pub(topic, message)).is_ok
             max_t = 5
             t = 0
             while not ret and t < max_t: 
                 try:
-                    ret = await mq.pub(topic, message).isok
+                    ret = (await mq.pub(topic, message)).is_ok
                 except:
                     ret = False
                 t += 1
