@@ -53,7 +53,7 @@ class XRedis(Singleton):
             self.__release_conn()
             print('创建新连接')
             pool = redis.ConnectionPool(
-                host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, max_connections=4, socket_timeout=60, socket_connect_timeout=30, socket_keepalive=True)
+                host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, socket_timeout=60, socket_connect_timeout=30, socket_keepalive=True, retry_on_timeout=True)
             self.conn = redis.StrictRedis(connection_pool=pool)
             # self.conn = redis.StrictRedis(host=self.host, port=self.port, db=self.db, password=self.password, decode_responses=True, socket_connect_timeout=1, socket_timeout=1)
             if self.conn.ping():
@@ -268,6 +268,7 @@ try:
     import coredis
 except:
     pass
+
 class XRedisAsync(Singleton):
     def __init__(self, host, password, port, db=0):
         if not self.need_init():
@@ -278,8 +279,7 @@ class XRedisAsync(Singleton):
         self.db = db
         self.locker = threading.Lock()
 
-        # pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, max_connections=4, socket_timeout=60, socket_connect_timeout=30, socket_keepalive=True)
-        pool = coredis.ConnectionPool.from_url('redis://:{}@{}:{}/{}'.format(self.password, self.host, self.port, self.db), decode_responses=True)
+        pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, socket_keepalive=True, retry_on_timeout=True)
         self.conn = coredis.StrictRedis(connection_pool=pool)
             
     async def __release_conn(self):
@@ -292,7 +292,7 @@ class XRedisAsync(Singleton):
         try:
             await self.__release_conn()
             print('创建新连接')
-            pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, max_connections=4, socket_timeout=60, socket_connect_timeout=30, socket_keepalive=True)
+            pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, socket_keepalive=True, retry_on_timeout=True)
             self.conn = coredis.StrictRedis(connection_pool=pool)
 
             if await self.conn.ping():
@@ -362,7 +362,10 @@ class XRedisAsync(Singleton):
 
     async def get(self, key):
         conn = self.__get_connection()
-        return await conn.get(key)
+        try:
+            return await conn.get(key)
+        except Exception as e:
+            return None
 
     async def delkey(self, key):
         conn = self.__get_connection()
